==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/lt-LT/admin/users/table.php <==
<?php

return array(
    'activated'  			=> 'Aktyvus',
    'allow'  				=> 'Leisti',
    'checkedout'  			=> 'Turtas',
    'created_at' 			=> 'Sukurta',
    'createuser' 			=> 'Sukurti naudotoją',
    'deny'  				=> 'Neleisti',
    'email'      			=> 'El. paštas',
    'employee_num'      	=> 'Darbuotojo nr.',
    'first_name' 			=> 'Vardas',
    'groupnotes'			=> 'Pasirinkite grupę, kurią norite priskirti naudotojui ir nepamirškite, kad naudotojas gauna jam priskirtos grupės prieigos teises. Norėdami panaikinti grupių pasirinkimą, naudokite Ctrl + spustelėjimas (arba cmd + spustelėjimas, jei naudojate MacOS).',
    'id'         			=> 'Id',
    'inherit'  				=> 'Paveldėti',
    'job' 					=> 'Pozicija',
    'last_login'  			=> 'Paskutinis prisijungimas',
    'last_name'  			=> 'Pavardė',
    'location'  			=> 'Vieta',
    'lock_passwords'		=> 'Prisijungimo duomenys negali būti keičiami šio diegimo metu.',
    'manager' 				=> 'Tiesioginis vadovas',
    'managed_locations'     => 'Valdomos vietos',
    'managed_users'         => 'Pavaldiniai',
    'name' 					=> 'Visas vardas',
    'nogroup'               => 'Dar nesukurta jokia grupė. Norėdami sukurti grupę, apsilankykite: ',
    'notes'                 => 'Pastabos',
    'password_confirm' 		=> 'Patvirtinti slaptažodį',
    'password' 				=> 'Slaptažodis',
    'phone'  				=> 'Telefono Nr.',
    'show_current'          => 'Rodyti esamus naudotojus',
    'show_deleted'          => 'Rodyti panaikintus naudotojus',
    'title' 				=> 'Antraštė',
	'to_restore_them'		=> 'juos atkurti.',
    'total_assets_cost'     => "Bendra turto vertė",
    'updateuser' 			=> 'Atnaujinti naudotoją',
    'username' 				=> 'Naudotojo vardas',
	'user_deleted_text' 	=> 'Šis naudotojas buvo pažymėtas kaip panaikintas.',
    'username_note' 		=> '(Tai naudojama tik „Active Directory“ susiejimui, o ne prisijungimui.)',
    'cloneuser'             => 'Klonuoti naudotoją',
    'viewusers' 			=> 'Peržiūrėti naudotojus',
);

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/lt-LT/admin/users/table.php <==
<?php

return array(
    'activated'  			=> 'Aktyvus',
    'allow'  				=> 'Leisti',
    'checkedout'  			=> 'Turtas',
    'created_at' 			=> 'Sukurta',
    'createuser' 			=> 'Sukurti naudotoją',
    'deny'  				=> 'Neleisti',
    'email'      			=> 'El. paštas',
    'employee_num'      	=> 'Darbuotojo nr.',
    'first_name' 			=> 'Vardas',
    'groupnotes'			=> 'Pasirinkite grupę, kurią norite priskirti naudotojui ir nepamirškite, kad naudotojas gauna jam priskirtos grupės prieigos teises. Norėdami panaikinti grupių pasirinkimą, naudokite Ctrl + spustelėjimas (arba cmd + spustelėjimas, jei naudojate MacOS).',
    'id'         			=> 'Id',
    'inherit'  				=> 'Paveldėti',
    'job' 					=> 'Pareigos',
    'last_login'  			=> 'Paskutinis prisijungimas',
    'last_name'  			=> 'Pavardė',
    'location'  			=> 'Vieta',
    'lock_passwords'		=> 'Prisijungimo duomenys negali būti keičiami šio diegimo metu.',
    'manager' 				=> 'Tiesioginis vadovas',
    'managed_locations'     => 'Valdomos vietos',
    'managed_users'         => 'Pavaldiniai',
    'name' 					=> 'Visas vardas',
    'nogroup'               => 'Dar nesukurta jokia grupė. Norėdami sukurti grupę, apsilankykite: ',
    'notes'                 => 'Pastabos',
    'password_confirm' 		=> 'Patvirtinti slaptažodį',
    'password' 				=> 'Slaptažodis',
    'phone'  				=> 'Telefono Nr.',
    'show_current'          => 'Rodyti esamus naudotojus',
    'show_deleted'          => 'Rodyti panaikintus naudotojus',
    'title' 				=> 'Pareigos',
	'to_restore_them'		=> 'juos atkurti.',
    'total_assets_cost'     => "Bendra turto vertė",
    'updateuser' 			=> 'Atnaujinti naudotoją',
    'username' 				=> 'Naudotojo vardas',
	'user_deleted_text' 	=> 'Šis naudotojas buvo pažymėtas kaip panaikintas.',
    'username_note' 		=> '(Tai naudojama tik „Active Directory“ susiejimui, o ne prisijungimui.)',
    'cloneuser'             => 'Klonuoti naudotoją',
    'viewusers' 			=> 'Peržiūrėti naudotojus',
);
